﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections;
using Infragistics.Controls.Grids;

namespace CustomGridColumnsDemo.Assets.Columns
{
    public class ComboBoxColumn : EditableColumn
    {
        #region Constructor
        #endregion

        #region Properties

        #region ItemSource

        /// <summary>
        /// Identifies the <see cref="ItemSource"/> dependency property. 
        /// </summary>
        public static readonly DependencyProperty ItemsSourceProperty = DependencyProperty.Register("ItemsSource", typeof(IEnumerable), typeof(ComboBoxColumn), new PropertyMetadata(new PropertyChangedCallback(ItemsSourceChanged)));

        /// <summary>
        /// Gets or sets a collection used to generate the content of the <see cref="ItemsControl"/> 
        /// </summary>
        public IEnumerable ItemsSource
        {
            get { return (IEnumerable)this.GetValue(ItemsSourceProperty); }
            set { this.SetValue(ItemsSourceProperty, value); }
        }

        private static void ItemsSourceChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
        {
            ComboBoxColumn col = (ComboBoxColumn)obj;
            col.OnPropertyChanged("ItemsSource");
        }

        #endregion // ItemSource

        #region DisplayMemberPath

        /// <summary>
        /// Identifies the <see cref="DisplayMemberPath"/> dependency property. 
        /// </summary>
        public static readonly DependencyProperty DisplayMemberPathProperty = DependencyProperty.Register("DisplayMemberPath", typeof(string), typeof(ComboBoxColumn), new PropertyMetadata(new PropertyChangedCallback(DisplayMemberPathChanged)));

        /// <summary>
        /// Gets or sets a path to a value on the source object to serve as the visual representation of the object.
        /// </summary>
        public string DisplayMemberPath
        {
            get { return (string)this.GetValue(DisplayMemberPathProperty); }
            set { this.SetValue(DisplayMemberPathProperty, value); }
        }

        private static void DisplayMemberPathChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
        {
            ComboBoxColumn col = (ComboBoxColumn)obj;
            col.OnPropertyChanged("DisplayMemberPath");
        }

        #endregion // DisplayMemberPath

        #region ItemTemplate

        /// <summary>
        /// Identifies the <see cref="ItemTemplate"/> dependency property. 
        /// </summary>
        public static readonly DependencyProperty ItemTemplateProperty = DependencyProperty.Register("ItemTemplate", typeof(DataTemplate), typeof(ComboBoxColumn), new PropertyMetadata(new PropertyChangedCallback(ItemTemplateChanged)));

        /// <summary>
        /// Gets or sets the <see cref="DataTemplate"/> used to display each item.
        /// </summary>
        public string ItemTemplate
        {
            get { return (string)this.GetValue(ItemTemplateProperty); }
            set { this.SetValue(ItemTemplateProperty, value); }
        }

        private static void ItemTemplateChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
        {
            ComboBoxColumn col = (ComboBoxColumn)obj;
            col.OnPropertyChanged("ItemTemplate");
        }

        #endregion // ItemTemplate

        #region ComboBoxStyle

        /// <summary>
        /// Identifies the <see cref="ComboBoxStyle"/> dependency property. 
        /// </summary>
        public static readonly DependencyProperty ComboBoxStyleProperty = DependencyProperty.Register("ComboBoxStyle", typeof(Style), typeof(ComboBoxColumn), new PropertyMetadata(new PropertyChangedCallback(ComboBoxStyleChanged)));

        /// <summary>
        /// Gets or sets the style used by ComboBox element when it is rendered
        /// </summary>
        public string ComboBoxStyle
        {
            get { return (string)this.GetValue(ComboBoxStyleProperty); }
            set { this.SetValue(ComboBoxStyleProperty, value); }
        }

        private static void ComboBoxStyleChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
        {
            ComboBoxColumn col = (ComboBoxColumn)obj;
            col.OnPropertyChanged("ComboBoxStyle");
        }

        #endregion // ComboBoxStyle

        #endregion

        #region Overrides

        /// <summary>
        /// Generates a new <see cref="ComboBoxColumnContentProvider"/> that will be used to generate content for <see cref="Cell"/> objects for this <see cref="Column"/>.
        /// </summary>
        /// <returns></returns>
        protected override Infragistics.Controls.Grids.Primitives.ColumnContentProviderBase GenerateContentProvider()
        {
            return new ComboBoxColumnContentProvider();
        }

        #endregion

    }
}
